@@ -68,15 +68,12 @@ module Database.PostgreSQL.Simple.Queue
   ) where
 import           Control.Monad
 import           Control.Monad.Catch
-import           Control.Monad.IO.Class
 import           Data.Aeson
-import qualified Data.ByteString                         as BS
 import           Data.Function
 import           Data.Int
 import           Data.Maybe
 import           Data.Text                               (Text)
 import           Data.Time
-import           Data.UUID                               (UUID)
 import           Database.PostgreSQL.Simple              (Connection, Only (..))
 import qualified Database.PostgreSQL.Simple              as Simple
 import           Database.PostgreSQL.Simple.FromField
@@ -87,13 +84,12 @@ import           Database.PostgreSQL.Simple.ToField
 import           Database.PostgreSQL.Simple.ToRow
 import           Database.PostgreSQL.Simple.Transaction
 import           Database.PostgreSQL.Transact
-import           System.Random
 import           Data.Monoid
 import           Data.String
 -------------------------------------------------------------------------------
 ---  Types
 -------------------------------------------------------------------------------
-newtype PayloadId = PayloadId { unPayloadId :: UUID }
+newtype PayloadId = PayloadId { unPayloadId :: Int64 }
   deriving (Eq, Show, FromField, ToField)
 
 instance FromRow PayloadId where
@@ -147,21 +143,8 @@ instance FromRow Payload where
 -------------------------------------------------------------------------------
 ---  DB API
 -------------------------------------------------------------------------------
-withSchema :: String -> Simple.Query -> Simple.Query
-withSchema schemaName q = "SET search_path TO " <> fromString schemaName <> "; " <> q
-
 notifyName :: IsString s => String -> s
-notifyName schemaName = fromString $ schemaName <> "_enqueue"
-
-retryOnUniqueViolation :: MonadCatch m => m a -> m a
-retryOnUniqueViolation act = try act >>= \case
-  Right x -> return x
-  Left e ->
-    if Simple.sqlState e == "23505" &&
-       "duplicate key" `BS.isPrefixOf` Simple.sqlErrorMsg e then
-      act
-    else
-      throwM e
+notifyName tableName = fromString $ tableName <> "_enqueue"
 
 {-| Enqueue a new JSON value into the queue. This particularly function
     can be composed as part of a larger database transaction. For instance,
@@ -175,16 +158,14 @@ retryOnUniqueViolation act = try act >>= \case
  @
 -}
 enqueueDB :: String -> Value -> DB PayloadId
-enqueueDB schemaName value = retryOnUniqueViolation $ do
-  pid <- liftIO randomIO
-  execute (withSchema schemaName $ [sql|
-    INSERT INTO payloads (id, value)
-    VALUES (?, ?);
-    NOTIFY |] <> " " <> notifyName schemaName <>
-    ";"
+enqueueDB tableName value =
+  fmap head $ query ([sql|
+    NOTIFY |] <> " " <> notifyName tableName <> ";" <> [sql|
+    INSERT INTO|] <> " " <> fromString tableName <> " " <> [sql|(value)
+    VALUES (?)
+    RETURNING id;|]
     )
-    (pid, value)
-  return $ PayloadId pid
+    $ Only value
 
 {-| Return a the oldest 'Payload' in the 'Enqueued' state, or 'Nothing'
     if there are no payloads. This function is not necessarily useful by
@@ -193,12 +174,12 @@ enqueueDB schemaName value = retryOnUniqueViolation $ do
     blocking version utilizing PostgreSQL's NOTIFY and LISTEN, see 'lock'
 -}
 tryLockDB :: String -> DB (Maybe Payload)
-tryLockDB schemaName = fmap listToMaybe $ query_ $ withSchema schemaName
-  [sql| UPDATE payloads
+tryLockDB tableName = fmap listToMaybe $ query_ $
+  [sql| UPDATE|] <> " " <> fromString tableName <> " " <> [sql|
         SET state='locked'
         WHERE id in
           ( SELECT id
-            FROM payloads
+            FROM|] <> " " <> fromString tableName <> " " <> [sql|
             WHERE state='enqueued'
             ORDER BY created_at ASC
             LIMIT 1
@@ -212,8 +193,8 @@ tryLockDB schemaName = fmap listToMaybe $ query_ $ withSchema schemaName
     useful. The DB version is provided for completeness.
 -}
 unlockDB :: String -> PayloadId -> DB ()
-unlockDB schemaName payloadId = void $ execute (withSchema schemaName
-  [sql| UPDATE payloads
+unlockDB tableName payloadId = void $ execute (
+  [sql| UPDATE|] <> " " <> fromString tableName <> " " <> [sql|
         SET state='enqueued'
         WHERE id=? AND state='locked'
   |])
@@ -221,8 +202,8 @@ unlockDB schemaName payloadId = void $ execute (withSchema schemaName
 
 -- | Transition a 'Payload' to the 'Dequeued' state.
 dequeueDB :: String -> PayloadId -> DB ()
-dequeueDB schemaName payloadId = void $ execute (withSchema schemaName
-  [sql| UPDATE payloads
+dequeueDB tableName payloadId = void $ execute (
+  [sql| UPDATE|] <> " " <> fromString tableName <> " " <> [sql|
         SET state='dequeued'
         WHERE id=?
   |])
@@ -230,9 +211,9 @@ dequeueDB schemaName payloadId = void $ execute (withSchema schemaName
 
 -- | Get the number of rows in the 'Enqueued' state.
 getCountDB :: String -> DB Int64
-getCountDB schemaName = fmap (fromOnly . head) $ query_ $ withSchema schemaName
+getCountDB tableName = fmap (fromOnly . head) $ query_ $
   [sql| SELECT count(*)
-        FROM payloads
+        FROM|] <> " " <> fromString tableName <> " " <> [sql|
         WHERE state='enqueued'
   |]
 -------------------------------------------------------------------------------
@@ -242,7 +223,7 @@ getCountDB schemaName = fmap (fromOnly . head) $ query_ $ withSchema schemaName
     which can be composed with other queries in a single transaction.
 -}
 enqueue :: String -> Connection -> Value -> IO PayloadId
-enqueue schemaName conn value = runDBT (enqueueDB schemaName value) ReadCommitted conn
+enqueue tableName conn value = runDBT (enqueueDB tableName value) ReadCommitted conn
 
 {-| Return a the oldest 'Payload' in the 'Enqueued' state or 'Nothing'
     if there are no payloads. For a blocking version utilizing PostgreSQL's
@@ -250,12 +231,12 @@ enqueue schemaName conn value = runDBT (enqueueDB schemaName value) ReadCommitte
     'Serializable' transaction.
 -}
 tryLock :: String -> Connection -> IO (Maybe Payload)
-tryLock schemaName conn = runDBTSerializable (tryLockDB schemaName) conn
+tryLock tableName conn = runDBTSerializable (tryLockDB tableName) conn
 
 notifyPayload :: String -> Connection -> IO ()
-notifyPayload schemaName conn = do
+notifyPayload tableName conn = do
   Notification {..} <- getNotification conn
-  unless (notificationChannel == notifyName schemaName) $ notifyPayload schemaName conn
+  unless (notificationChannel == notifyName tableName) $ notifyPayload tableName conn
 
 {-| Return the oldest 'Payload' in the 'Enqueued' state or block until a
     payload arrives. This function utilizes PostgreSQL's LISTEN and NOTIFY
@@ -263,14 +244,14 @@ notifyPayload schemaName conn = do
     waiting for new payloads, without scarficing promptness.
 -}
 lock :: String -> Connection -> IO Payload
-lock schemaName conn = bracket_
-  (Simple.execute_ conn $ "LISTEN " <> notifyName schemaName)
-  (Simple.execute_ conn $ "UNLISTEN " <> notifyName schemaName)
+lock tableName conn = bracket_
+  (Simple.execute_ conn $ "LISTEN " <> notifyName tableName)
+  (Simple.execute_ conn $ "UNLISTEN " <> notifyName tableName)
   $ fix $ \continue -> do
-      m <- tryLock schemaName conn
+      m <- tryLock tableName conn
       case m of
         Nothing -> do
-          notifyPayload schemaName conn
+          notifyPayload tableName conn
           continue
         Just x -> return x
 
@@ -279,15 +260,15 @@ lock schemaName conn = bracket_
     shutdown. For a DB API version see 'unlockDB'
 -}
 unlock :: String -> Connection -> PayloadId -> IO ()
-unlock schemaName conn x = runDBTSerializable (unlockDB schemaName x) conn
+unlock tableName conn x = runDBTSerializable (unlockDB tableName x) conn
 
 -- | Transition a 'Payload' to the 'Dequeued' state. his functions runs
 --   'dequeueDB' as a 'Serializable' transaction.
 dequeue :: String -> Connection -> PayloadId -> IO ()
-dequeue schemaName conn x = runDBTSerializable (dequeueDB schemaName x) conn
+dequeue tableName conn x = runDBTSerializable (dequeueDB tableName x) conn
 
 {-| Get the number of rows in the 'Enqueued' state. This function runs
     'getCountDB' in a 'ReadCommitted' transaction.
 -}
 getCount :: String -> Connection -> IO Int64
-getCount schemaName = runDBT (getCountDB schemaName) ReadCommitted
+getCount tableName = runDBT (getCountDB tableName) ReadCommitted
