@@ -17,37 +17,37 @@ import           Test.Hspec.DB
 main :: IO ()
 main = hspec spec
 
-schemaName :: String
-schemaName = "queue"
+tableName :: String
+tableName = "queue"
 
 spec :: Spec
-spec = describeDB (migrate schemaName) "Database.Queue" $ do
+spec = describeDB (migrate tableName) "Database.Queue" $ do
   itDB "empty locks nothing" $
-    tryLockDB schemaName `shouldReturn` Nothing
+    tryLockDB tableName `shouldReturn` Nothing
 
   itDB "empty gives count 0" $
-    getCountDB schemaName `shouldReturn` 0
+    getCountDB tableName `shouldReturn` 0
 
   itDB "enqueues/tryLocks/unlocks" $ do
-    payloadId <- enqueueDB schemaName $ String "Hello"
-    getCountDB schemaName `shouldReturn` 1
+    payloadId <- enqueueDB tableName $ String "Hello"
+    getCountDB tableName `shouldReturn` 1
 
-    Just Payload {..} <- tryLockDB schemaName
-    getCountDB schemaName `shouldReturn` 0
+    Just Payload {..} <- tryLockDB tableName
+    getCountDB tableName `shouldReturn` 0
 
     pId `shouldBe` payloadId
     pValue `shouldBe` String "Hello"
-    tryLockDB schemaName `shouldReturn` Nothing
+    tryLockDB tableName `shouldReturn` Nothing
 
-    unlockDB schemaName pId
-    getCountDB schemaName `shouldReturn` 1
+    unlockDB tableName pId
+    getCountDB tableName `shouldReturn` 1
 
   itDB "tryLocks/dequeues" $ do
-    Just Payload {..} <- tryLockDB schemaName
-    getCountDB schemaName `shouldReturn` 0
+    Just Payload {..} <- tryLockDB tableName
+    getCountDB tableName `shouldReturn` 0
 
-    dequeueDB schemaName pId `shouldReturn` ()
-    tryLockDB schemaName `shouldReturn` Nothing
+    dequeueDB tableName pId `shouldReturn` ()
+    tryLockDB tableName `shouldReturn` Nothing
 
   it "enqueues and dequeues concurrently tryLock" $ \testDB -> do
     let withPool' = withPool testDB
@@ -57,18 +57,18 @@ spec = describeDB (migrate schemaName) "Database.Queue" $ do
     ref <- newIORef []
 
     loopThreads <- replicateM 10 $ async $ fix $ \next -> do
-      mpayload <- withPool' $ tryLock schemaName
+      mpayload <- withPool' $ tryLock tableName
       case mpayload of
         Nothing -> next
         Just Payload {..}  -> do
           lastCount <- atomicModifyIORef ref
                      $ \xs -> (pValue : xs, length xs + 1)
-          withPool' $ \c -> dequeue schemaName c pId
+          withPool' $ \c -> dequeue tableName c pId
           when (lastCount < elementCount) next
 
     -- Fork a hundred threads and enqueue an index
     forM_ [0 .. elementCount - 1] $ \i ->
-      forkIO $ void $ withPool' $ \c -> enqueue schemaName c $ toJSON i
+      forkIO $ void $ withPool' $ \c -> enqueue tableName c $ toJSON i
 
     waitAnyCancel loopThreads
     Just decoded <- mapM (decode . encode) <$> readIORef ref
@@ -82,15 +82,15 @@ spec = describeDB (migrate schemaName) "Database.Queue" $ do
     ref <- newIORef []
 
     loopThreads <- replicateM 10 $ async $ fix $ \next -> do
-      Payload {..} <- withPool' $ lock schemaName
+      Payload {..} <- withPool' $ lock tableName
       lastCount <- atomicModifyIORef ref
                  $ \xs -> (pValue : xs, length xs + 1)
-      withPool' $ \c -> dequeue schemaName c pId
+      withPool' $ \c -> dequeue tableName c pId
       when (lastCount < elementCount) next
 
     -- Fork a hundred threads and enqueue an index
     forM_ [0 .. elementCount - 1] $ \i -> forkIO $ void $ withPool' $ \c ->
-      enqueue schemaName c $ toJSON i
+      enqueue tableName c $ toJSON i
 
     waitAnyCancel loopThreads
     Just decoded <- mapM (decode . encode) <$> readIORef ref
